Contributing to django-versionlog

我们欢迎report Issues 或者 pull requests。 在贡献代码之前请阅读以下指引。

如果你想提出issue，在此之前请查找已存在或者相类似的issue，从而保证不存在冗余。

新建 Issues： 新建issues 时请提供详细的描述、截屏或者短视频来辅助我们定位问题。

分支管理 Pull Requests ：我们欢迎大家贡献代码来使我们的 django-versionlog 更加强大，代码团队会监控所有的pull request, 我们会做相应的代码检查和测试，测试通过之后我们就会接纳PR ，但是不会立即合并到master分支。

在完成一个pr之前请做一下确认:

从 master 或者 hotfix fork 你自己的分支。 在修改了代码之后请修改对应的文档和注释。 在新建的文件中请加入license 和copy right申明。 确保一致的代码风格。 做充分的测试。 然后，你可以提交你的代码到 新的分支，然后提交PR。 代码协议 MIT LICENSE 为 django-versionlog 的开源协议，你贡献的代码也会受此协议保护。